searchData={"items":[{"type":"module","title":"TelemetryMetricsAppsignal","doc":"AppSignal Reporter for [`Telemetry.Metrics`](https://github.com/beam-telemetry/telemetry_metrics) definitions.\n\nThis reporter is useful for getting [custom metrics](https://docs.appsignal.com/metrics/custom.html)\ninto AppSignal from your application. These custom metrics are especially\nuseful for building custom dashboards.\n\nTo use the reporter, first define a list of metrics as shown here:\n\n    def metrics, do:\n      [\n        summary(\"phoenix.endpoint.stop.duration\"),\n        last_value(\"vm.memory.total\"),\n        counter(\"my_app.my_server.call.exception\")\n      ]\n\nIt's recommended to start TelemetryMetricsAppsignal under a supervision tree,\neither in your main application or as recommended [here](https://hexdocs.pm/phoenix/telemetry.html#the-telemetry-supervisor)\nif using Phoenix:\n\n    {TelemetryMetricsAppsignal, [metrics: metrics()]}\n\nPutting that altogether, your configuration could look something like this:\n\n    def start_link(_arg) do\n      children = [\n        {TelemetryMetricsAppsignal, [metrics: metrics()]},\n        ...\n      ]\n      Supervisor.init(children, strategy: :one_for_one)\n    end\n\n    defp metrics, do:\n      [\n        summary(\"phoenix.endpoint.stop.duration\"),\n        last_value(\"vm.memory.total\"),\n        counter(\"my_app.my_server.call.exception\")\n      ]\n\n  Optionally you can register a name:\n\n      {TelemetryMetricsAppsignal,\n        [metrics: metrics(), name: MyTelemetryMetricsAppsignal]}\n\nThe following table shows how `Telemetry.Metrics` metrics map to [AppSignal\nmetrics](https://docs.appsignal.com/metrics/custom.html#metric-types):\n\n| Telemetry.Metrics     | AppSignal |\n|-----------------------|-----------|\n| `last_value`          | `gauge` |\n| `counter`             | `counter` |\n| `sum`                 | `counter`, increased by the provided value |\n| `summary`             | `measurement` |\n| `distribution`        | Not supported |","ref":"TelemetryMetricsAppsignal.html"},{"type":"function","title":"TelemetryMetricsAppsignal.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"TelemetryMetricsAppsignal.html#child_spec/1"},{"type":"function","title":"TelemetryMetricsAppsignal.handle_event/4","doc":"","ref":"TelemetryMetricsAppsignal.html#handle_event/4"},{"type":"function","title":"TelemetryMetricsAppsignal.start_link/1","doc":"","ref":"TelemetryMetricsAppsignal.html#start_link/1"},{"type":"type","title":"TelemetryMetricsAppsignal.metric/0","doc":"","ref":"TelemetryMetricsAppsignal.html#t:metric/0"},{"type":"type","title":"TelemetryMetricsAppsignal.option/0","doc":"","ref":"TelemetryMetricsAppsignal.html#t:option/0"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [1.5.0] - 2024-06-19","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Support for `telemetry` v1.0 [@JVMartyns](https://github.com/JVMartyns).\n\n## [1.4.0] - 2023-10-27","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Support for `:keep` and `:drop` options for filtering events by [@jfpedroza](https://github.com/jfpedroza).\n\n## [1.3.0] - 2022-11-26","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Support calculating metrics using both `measurements` and `metadata`, as introduced in `telemetry_metrics` [v0.6.0](https://github.com/beam-telemetry/telemetry_metrics/blob/main/CHANGELOG.md#060), by [@quinlanjager](https://github.com/quinlanjager).\n\n## [1.2.1] - 2021-12-06","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Improved performance of handling events by [@nallwhy](https://github.com/nallwhy).\n\n## [1.2.0] - 2021-09-30","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Added support for telemetry 1.0.\n\n## [1.1.0] - 2021-01-21","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Added support for Appsignal 2.0.\n\n## [1.0.0] - 2020-05-27","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- `TelemetryMetricsAppsignal` is now implemented as a `GenServer` and performs cleanup\n  of telemetry handlers upon termination (kudos to @bradleygolden).","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Marked `jason` as an optional dependency - it's only required by `appsignal` when testing.\n- Suppressed warning when measurement was missing from an event.\n\n## [0.1.1] - 2020-05-17","ref":"changelog.html#fixed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fixed using `tag_values` to generate tags from metadata.\n\n## [0.1.0] - 2020-04-07","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Implemented reporting all `Telemetry.Metrics` measurements to AppSignal.","ref":"changelog.html#added"},{"type":"extras","title":"TelemetryMetricsAppsignal","doc":"# TelemetryMetricsAppsignal\n\n[![GitHub Workflow Status (branch)](https://img.shields.io/github/actions/workflow/status/surgeventures/telemetry_metrics_appsignal/test.yml?branch=main)](https://github.com/surgeventures/telemetry_metrics_appsignal/actions/workflows/test.yml?query=branch%3Amain)\n[![Hex pm](http://img.shields.io/hexpm/v/telemetry_metrics_appsignal)](https://hex.pm/packages/telemetry_metrics_appsignal)\n\nA `Telemetry.Metrics` reporter that pushes metrics to AppSignal. Requires [the AppSignal library](https://hexdocs.pm/appsignal) to be installed and configured.","ref":"readme.html"},{"type":"extras","title":"Installation - TelemetryMetricsAppsignal","doc":"Add `telemetry_metrics_appsignal` to your `mix.exs` file:\n\n```elixir\ndef deps do\n  [\n    {:telemetry_metrics_appsignal, \"~> 1.0\"}\n  ]\nend\n```\n\nSee the documentation on [Hexdocs](https://hexdocs.pm/telemetry_metrics_appsignal/TelemetryMetricsAppsignal.html) for more information.","ref":"readme.html#installation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}